use crate::database::controller::connector::establish_connection;
use crate::database::model::addresses::Address;
use crate::diesel::RunQueryDsl;
use crate::helper::settings::Settings;
use diesel::{ExpressionMethods, JoinOnDsl, QueryDsl};
use rocket::State;

/// Reads all addresses for entity_id specified
/// Returns None if error occurred or there are no addresses
pub fn get_addresses_for_entity(
    settings: &State<Settings>,
    entity_id_to_get: uuid::Uuid,
) -> Option<Vec<Address>> {
    use crate::schema::addresses::dsl::*;
    use crate::schema::addresses_entities::dsl::*;

    let connection = establish_connection(settings);

    let data: Result<Vec<Address>, diesel::result::Error> = addresses
        .left_join(addresses_entities.on(id.eq(address_id)))
        .filter(entitiy_id.eq(entity_id_to_get))
        .select((id, title, street, number, zipcode, city, country))
        .load(&connection);

    match data {
        Ok(data_addresses) => Some(data_addresses),
        Err(e) => {
            error!(
                "Error reading addresses for {} from database: {}",
                entity_id_to_get, e
            );
            None
        }
    }
}

pub fn get_addresses_for_entity_only_one_allowed(
    settings: &State<Settings>,
    entity_id_to_get: uuid::Uuid,
) -> Option<Address> {
    match get_addresses_for_entity(settings, entity_id_to_get) {
        Some(addresses) => {
            if addresses.len() == 0 {
                None
            } else if addresses.len() != 1 {
                error!("There is more then one address saved for entity {}, but called with get_addresses_for_entity_only_one_allowed()! Check for data inconsistency.", entity_id_to_get);
                None
            } else {
                Some(addresses.first().unwrap().clone()) //Yes, we are allowed to unwrap because we checked that there is exact one element 3 lines before
            }
        }
        None => None,
    }
}
