use rocket::State;
use crate::helper::settings::Settings;
use crate::modules::member_management::model::member::CreateMemberForm;
use crate::database::controller::connector::establish_connection;
use crate::schema::entities::dsl::entities;
use diesel::{RunQueryDsl, ExpressionMethods};
use crate::schema::entities::dsl::entity_id;
use crate::schema::members::dsl::members;
use crate::database::model::members::CreateMember;
use crate::helper::forms::into_option;
use chrono::NaiveDate;
use crate::database::controller::members_groups::add_member_to_group;
use diesel::result::Error;

pub fn create_member(settings: &State<Settings>, form: CreateMemberForm) -> Result<uuid::Uuid, diesel::result::Error>{
    let connection = establish_connection(settings);

    let entity_id_result: Result<uuid::Uuid, diesel::result::Error> =diesel::insert_into(entities).default_values().returning(crate::schema::entities::dsl::entity_id).get_result(&connection);
    let id = match entity_id_result{
        Ok(id) => id,
        Err(e) => {
            error!("Konnte keine entity anlegen: {}", e);
            return Err(e)
        }
    };

    use crate::schema::members::dsl::*;

    let personnel_number2 = if form.personnel_number.is_empty(){
        None
    }else{
        match form.personnel_number.parse::<i32>(){
            Ok(num) => Some(num),
            Err(e) => {
                warn!("Couldn't parse personnel number: {}", e);
                None
            }
        }
    };

    let entrance_date2 = if form.entrance_date.is_empty(){
        None
    }else {
        match NaiveDate::parse_from_str(&form.entrance_date, "%Y-%m-%d") {
            Ok(date) => Some(date),
            Err(e) => {
                warn!("Couldn't parse date: {}", e);
                None
            }
        }
    };

    let member = CreateMember{
        entity_id: id,
        firstname: form.firstname,
        lastname: form.lastname,
        sex: form.sex.parse::<i16>().unwrap(),
        salutation: form.salutation,
        academic_titles: into_option(form.academic_titles),
        personnel_number: personnel_number2,
        entrance_date: entrance_date2
    };

    match add_member_to_group(settings, id, uuid::Uuid::parse_str("00000000-0000-0000-0000-000000000000").unwrap()){
        Ok(_) => {},
        Err(_) => {}
    }

    match diesel::insert_into(members).values(member).execute(&connection){
        Ok(_) => Ok(id),
        Err(e) => {
            error!("Couldn't create member: {}", e);
            Err(e)
        }
    }

}