use crate::database::controller::connector::establish_connection;
use crate::database::model::addresses::Address;
use crate::helper::settings::Settings;
use crate::schema::addresses::columns::id;
use crate::schema::addresses::dsl::addresses;
use crate::schema::addresses_entities::columns::{address_id, entitiy_id};
use crate::schema::addresses_entities::dsl::addresses_entities;
use diesel::{ExpressionMethods, RunQueryDsl};
use rocket::State;

pub fn insert_address(
    settings: &State<Settings>,
    new_address: Address,
    belongs_to: uuid::Uuid,
) -> bool {
    let connection = establish_connection(settings);

    let address = diesel::insert_into(addresses)
        .default_values()
        .get_result(&connection);

    let address: Address = match address {
        Ok(address) => address,
        Err(e) => {
            warn!("Couldn't receive inserted address: {}", e);
            return false;
        }
    };

    let mut new_address = new_address;
    new_address.id = address.id;

    let update = diesel::update(addresses)
        .filter(id.eq(address.id))
        .set(&new_address)
        .get_result(&connection);

    let address: Address = match update {
        Ok(address) => address,
        Err(e) => {
            warn!("Couldn't receive updated address: {}", e);
            return false;
        }
    };

    let result = diesel::insert_into(addresses_entities)
        .values((address_id.eq(address.id), entitiy_id.eq(belongs_to.clone())))
        .execute(&connection);

    match result {
        Ok(_) => true,
        Err(e) => {
            warn!(
                "Couldn't insert new address: {} for entity {}",
                e, belongs_to
            );
            false
        }
    }
}
