use crate::helper::settings::Settings;
use rocket::State;
use crate::database::controller::connector::establish_connection;
use diesel::{ExpressionMethods, RunQueryDsl, JoinOnDsl, QueryDsl, sql_query};
use crate::database::model::units::Unit;
use crate::schema::units_members::dsl::units_members;
use crate::schema::groups::columns::entity_id;
use diesel::pg::types::sql_types::Uuid;

pub fn add_member_to_unit(settings: &State<Settings>, member_id2: uuid::Uuid, unit_id2: uuid::Uuid, crew2: i16) -> Result<(), diesel::result::Error>{
    use crate::schema::units_members::dsl::*;

    let connection = establish_connection(settings);

    match diesel::insert_into(units_members).values((unit_id.eq(unit_id2), member_id.eq(member_id2), crew.eq(crew2))).execute(&connection){
        Ok(_) => Ok(()),
        Err(e) => {
            error!("Couldn't put member in unit: {}", e);
            Err(e)
        }
    }
}

pub fn remove_member_from_unit(settings: &State<Settings>, member_id2: uuid::Uuid, unit_id2: uuid::Uuid) -> Result<(), diesel::result::Error>{
    use crate::schema::units_members::dsl::*;

    let connection = establish_connection(settings);

    match diesel::delete(units_members.filter(unit_id.eq(unit_id2))).execute(&connection){
        Ok(_) => Ok(()),
        Err(e) => {
            error!("Couldn't remove member from unit: {}", e);
            Err(e)
        }
    }
}

pub fn get_members_units(settings: &State<Settings>, member_id2: uuid::Uuid) -> Result<Vec<Unit>, diesel::result::Error>{
    use crate::schema::units::dsl::*;
    use crate::schema::units_members::dsl::*;
    use crate::database::model::units::Unit;

    let connection = establish_connection(settings);

    let units_list : Result<Vec<Unit>, diesel::result::Error> = sql_query("SELECT units.unit_id, name, crew FROM units RIGHT JOIN units_members um on units.unit_id = um.unit_id WHERE member_id = $1").bind::<Uuid, _>(member_id2).get_results(&connection);
    match units_list{
        Ok(list) => Ok(list),
        Err(e) => {
            error!("Couldn't get member units: {}", e);
            Err(e)
        }
    }
}