use crate::helper::mail_queue::queue::Mail;
use lettre_email::EmailBuilder;
use std::process::{Command, Output};
use std::io::Error;

pub fn send_mail(mail: Mail) -> Result<(), ()> {
    if mail.to.is_empty() || mail.subject.is_empty() || mail.from.is_empty() || mail.body.is_empty() {
        error!("Couldn't deliver mail {} because to, subject, from or body missing! Deleting mail!", mail.uuid);
        return Ok(())
    }

    let body = mail.body.escape_default().to_string();
    let subject = mail.subject.escape_default().to_string();

    let mut arg = String::from("echo \"");
    arg.push_str(&body);
    arg.push_str("\" | mailx --append='FROM: ");
    arg.push_str(&mail.from);
    arg.push_str("' ");
    if !mail.cc.is_empty(){
        arg.push_str("--append='CC:");
        for mail in mail.cc{
            arg.push_str(&(mail+","));
        }
        arg.push_str("' ")
    }
    if !mail.bcc.is_empty(){
        arg.push_str("--append='BCC:");
        for mail in mail.bcc{
            arg.push_str(&(mail+","));
        }
        arg.push_str("' ")
    }
    match mail.reply_to{
        Some(reply_to) => {
            arg.push_str(&format!("--append='Reply-To: {} ' ", reply_to))
        },
        None => ()
    }
    arg.push_str("-s \"");
    arg.push_str(&subject);
    arg.push_str("\" ");
    for receiver in mail.to{
        arg.push_str(&(receiver+" "));
    }

    match Command::new("sh").arg("-c").arg(arg).output(){
        Ok(output) => {
            if !output.status.success(){
                error!("Couldn't send mail: {} {} {}", output.status, String::from_utf8_lossy(&output.stderr), String::from_utf8_lossy(&output.stdout));
                Err(())
            }else {
                Ok(())
            }
        },
        Err(e) => {
            error!("Couldn't send mail: {}", e);
            Err(())
        }
    }
}