use crate::database::model::users::User;
use crate::modules::member_management::model::member::Member;
use chrono::{DateTime, Utc};
use std::collections::HashMap;
use std::sync::RwLock;

/// SessionCookieStorage stores all session cookies
#[derive(Deserialize)]
pub struct SessionCookieStorage {
    pub(crate) cookies: RwLock<HashMap<String, SessionCookie>>,
}

/// SessionCookie to store user data and ensure authentication
///
/// Should never be created manually! Use SessionCookieStorage::add instead!
#[derive(Deserialize, Clone)]
pub struct SessionCookie {
    /// unique id normally generated by SessionCookieStorage::add
    pub(crate) id: String,
    /// SessionCookie will get destroyed if called + current DateTime >= expires
    pub(crate) expires: DateTime<Utc>,
    pub(crate) user: User,
    /// contains member data after member was selected
    pub(crate) member: Option<Member>,
}

/// Error may occur while try to receive cookie out of SessionCookieStorage
///
/// Expired: specified cookie expiration date exceeded
/// NotFound: cookie with specified id wasn't found in Storage
#[derive(Debug, PartialEq)]
pub enum SessionCookieError {
    Expired,
    NotFound,
    Unavailable,
}
