use crate::modules::api::model::api_outcome::{ApiError, ApiErrorWrapper};
use rocket_contrib::json::Json;
use std::str::FromStr;

pub fn parse_qualification_id(
    qualification_id: String,
) -> Result<uuid::Uuid, Json<ApiErrorWrapper>> {
    match uuid::Uuid::from_str(&qualification_id) {
        Ok(id) => Ok(id),
        Err(e) => {
            warn!(
                "Couldn't parse qualification uuid send via API: {} {}",
                qualification_id, e
            );
            Err(Json(
                ApiError::new(400, "Qualifikations UUID ungültig".to_string()).to_wrapper(),
            ))
        }
    }
}

pub fn parse_category_id(category_id: String) -> Result<uuid::Uuid, Json<ApiErrorWrapper>> {
    match uuid::Uuid::from_str(&category_id) {
        Ok(id) => Ok(id),
        Err(e) => {
            warn!(
                "Couldn't parse category_id send via API: {} {}",
                category_id, e
            );
            Err(Json(
                ApiError::new(400, "Kategoreie ID ungültig".to_string()).to_wrapper(),
            ))
        }
    }
}
