use rocket::State;
use crate::helper::settings::Settings;
use crate::helper::session_cookies::model::SessionCookie;
use rocket_contrib::json::Json;
use crate::modules::api::model::api_outcome::ApiErrorWrapper;
use crate::database::model::units::RawUnit;
use crate::modules::api::member_management::controller::parser::parse_member_cookie;
use crate::database::controller::members::check_member_has_access;
use crate::database::controller::units::get_units;
use crate::helper::translate_diesel_error::translate_diesel;

#[get("/api/units", format = "json")]
pub fn read_unit_list(
    settings: State<Settings>,
    cookie: SessionCookie,
) -> Result<Json<Vec<RawUnit>>, Json<ApiErrorWrapper>> {
    let _caller = parse_member_cookie(cookie.member)?;

    match get_units(&settings){
        Ok(units) => Ok(Json(units)),
        Err(e) => Err(translate_diesel(e))
    }
}