use rocket::State;
use crate::helper::settings::Settings;
use crate::helper::session_cookies::model::SessionCookie;
use rocket_contrib::json::Json;
use crate::modules::api::model::api_outcome::{ApiErrorWrapper, ApiError};
use crate::modules::api::member_management::controller::parser::{parse_member_cookie, parse_uuid};
use crate::database::controller::members::check_member_has_access;
use crate::database::controller::units_members::add_member_to_unit;
use crate::helper::translate_diesel_error::translate_diesel;

#[put("/api/units/<unit_id>/members/<member_id>?<crew>", format = "json")]
pub fn put_member_in_unit(settings: State<Settings>, cookie: SessionCookie, unit_id: String, member_id: String, crew: i16) -> Result<(), Json<ApiErrorWrapper>>{
    let caller = parse_member_cookie(cookie.member)?;
    let member_id = parse_uuid(member_id)?;
    let unit_id = parse_uuid(unit_id)?;

    if !check_member_has_access(&settings, caller.entity_id, unit_id, crate::permissions::modules::units::members::EDIT){
        return Err(Json(ApiError::new(403, "Keine Berechtigung Einheitsmitglieder zu ändern!".to_string()).to_wrapper()))
    }

    match add_member_to_unit(&settings, member_id, unit_id, crew){
        Ok(_) => Ok(()),
        Err(e) => Err(translate_diesel(e))
    }
}