use crate::database::model::groups::GroupMemberCount;
use crate::database::model::roles::Role;
use crate::helper::sitebuilder::model::general::{Footer, Header};
use crate::helper::sitebuilder::model::sidebar::Sidebar;
use crate::schema::groups;

#[derive(Serialize)]
pub struct GroupsModule {
    pub header: Header,
    pub footer: Footer,
    pub sidebar: Sidebar,
    pub caller_permissions: Vec<String>,
    pub groups: Vec<GroupMemberCount>,
    pub roles: Vec<Role>,
}

#[derive(Serialize, Deserialize, Queryable, Clone)]
pub struct Group {
    pub(crate) entity_id: uuid::Uuid,
    pub(crate) group_name: String,
    pub(crate) group_description: Option<String>,
    pub(crate) selected: bool,
}

#[derive(Serialize, Deserialize, Queryable, Clone, AsChangeset)]
#[table_name = "groups"]
pub struct GroupData {
    pub(crate) entity_id: Option<uuid::Uuid>,
    pub(crate) group_name: Option<String>,
    pub(crate) group_description: Option<String>,
}

#[derive(Serialize, Deserialize, Queryable, Clone, AsChangeset)]
#[changeset_options(treat_none_as_null="true")]
#[table_name = "groups"]
pub struct GroupUpdateData {
    pub(crate) group_name: String,
    pub(crate) group_description: Option<String>,
}
