use crate::modules::member_management::model::groups::Group;
use chrono::NaiveDate;

#[derive(Queryable, Clone, Deserialize, Serialize)]
pub struct Member {
    pub(crate) entity_id: uuid::Uuid,
    pub(crate) users_id: Option<uuid::Uuid>,
    pub(crate) firstname: String,
    pub(crate) lastname: String,
    pub(crate) date_of_birth: Option<NaiveDate>,
    pub(crate) sex: Option<i16>,
    pub(crate) salutation: Option<String>,
    pub(crate) place_of_birth: Option<String>,
    pub(crate) academic_titles: Option<String>,
    pub(crate) personnel_number: Option<i32>,
    pub(crate) ui_language: Option<String>,
    pub(crate) nationality: Option<String>,
    pub(crate) entrance_date: Option<NaiveDate>,
    pub(crate) birth_name: Option<String>,
    pub(crate) iban: Option<String>,
    pub(crate) bic: Option<String>,
    pub(crate) permissions: Vec<String>,
    pub(crate) groups: Vec<Group>,
}

/// Data transmitted when user edit's member profiles
#[derive(FromForm, Queryable, Clone)]
pub struct MemberProfileForm {
    pub(crate) entity_id: String,
    pub(crate) firstname: String,
    pub(crate) lastname: String,
    pub(crate) date_of_birth: String,
    pub(crate) sex: String,
    pub(crate) salutation: String,
    pub(crate) place_of_birth: String,
    pub(crate) academic_titles: String,
    pub(crate) personnel_number: String,
    pub(crate) nationality: String,
    pub(crate) entrance_date: String,
    pub(crate) birth_name: String,
    pub(crate) address_id: String,
    pub(crate) address_street: String,
    pub(crate) address_number: String,
    pub(crate) address_zipcode: String,
    pub(crate) address_city: String,
    pub(crate) address_country: String,
    pub(crate) iban: String,
    pub(crate) bic: String,
}

//Helper struct to combine member + permissions the requesting user has (edit/view/none)
#[derive(Serialize)]
pub struct MemberWithAccess {
    pub(crate) member: Member,
    pub(crate) read: bool,
    pub(crate) write: bool,
    pub(crate) delete: bool,
}

#[derive(Serialize, FromForm)]
pub struct CreateMemberForm{
    pub(crate) firstname: String,
    pub(crate) lastname: String,
    pub(crate) sex: String,
    pub(crate) salutation: String,
    pub(crate) academic_titles: String,
    pub(crate) personnel_number: String,
    pub(crate) entrance_date: String,
}