use crate::helper::session_cookies::model::SessionCookie;
use rocket::State;
use crate::helper::settings::Settings;
use rocket::http::Status;
use rocket_contrib::templates::Template;
use crate::helper::check_access::check_access;
use crate::modules::member_management::controller::create_member::render;
use crate::modules::member_management::model::member::CreateMemberForm;
use rocket::request::Form;
use rocket::response::Redirect;
use crate::database::controller::create_member::create_member;

#[get("/portal/mm/add_member")]
pub fn member_management_add_member(
    cookie: SessionCookie,
    settings: State<Settings>,
) -> Result<Template, Status> {
    let caller = match cookie.member {
        //Unwraps member from cookie or send user to login if no member specified (user skipped member selection)
        Some(member) => member,
        None => return Err(Status::Unauthorized),
    };

    if !caller.has_permission("modules.member_management.profile.create".to_string()){
        return Err(Status::Unauthorized)
    }

    Ok(Template::render("module_member_management_create", render(&settings, caller)?))
}

#[post("/portal/mm/add_member", data="<create_member_form>")]
pub fn member_management_add_member_post(
    cookie: SessionCookie,
    settings: State<Settings>,
    create_member_form: Form<CreateMemberForm>
) -> Result<Redirect, Status> {
    let caller = match cookie.member {
        //Unwraps member from cookie or send user to login if no member specified (user skipped member selection)
        Some(member) => member,
        None => return Err(Status::Unauthorized),
    };

    if !caller.has_permission("modules.member_management.profile.create".to_string()){
        return Err(Status::Unauthorized)
    }

    match create_member(&settings, create_member_form.into_inner()){
        Ok(entity_id) => Ok(Redirect::to(format!("/portal/mm/profile?action=view&id={}",entity_id))),
        Err(_) => Err(Status::InternalServerError),
    }
}