use crate::database::controller::members::get_member_by_uuid;
use crate::helper::session_cookies::model::SessionCookie;
use crate::helper::settings::Settings;
use crate::modules::member_management::controller::member_profile::{
    handle_edit, handle_empty, handle_view,
};
use rocket::http::Status;
use rocket::State;
use rocket_contrib::templates::Template;
use std::str::FromStr;

#[get("/portal/mm/profile?<action>&<id>", rank=2)]
pub fn member_management_core_data_get(
    cookie: SessionCookie,
    settings: State<Settings>,
    action: Option<String>,
    id: Option<String>,
) -> Result<Template, Status> {
    let caller = match cookie.member {
        //Unwraps member from cookie or send user to login if no member specified (user skipped member selection)
        Some(member) => member,
        None => return Err(Status::Unauthorized),
    };

    let member_uuid = match id {
        Some(id) => match uuid::Uuid::from_str(&id) {
            Ok(uuid) => uuid,
            Err(e) => {
                warn!("Couldn't parse submitted member uuid (profile get): {}", e);
                return Err(Status::BadRequest);
            }
        },
        None => return handle_empty(caller),
    };

    let member = match get_member_by_uuid(member_uuid, &settings) {
        Some(member) => member,
        None => return Err(Status::NotFound),
    };

    match action {
        Some(action) => match action.as_ref() {
            "view" => handle_view(&settings, member, caller),
            "edit" => handle_edit(&settings, member, caller),
            _ => return Err(Status::NotFound),
        },
        None => handle_empty(caller),
    }
}
