use crate::database::controller::addresses::get_addresses_for_entity_only_one_allowed;
use crate::database::controller::member_update::update_member;
use crate::database::controller::members::get_member_by_uuid;
use crate::helper::session_cookies::model::SessionCookie;
use crate::helper::settings::Settings;
use crate::modules::member_management::controller::member_profile::{
   handle_edit, handle_view,
};
use crate::modules::member_management::model::member::MemberProfileForm;
use rocket::http::Status;
use rocket::request::Form;
use rocket::State;
use rocket_contrib::templates::Template;
use std::str::FromStr;

#[post("/portal/mm/profile?<action>&<id>", data = "<form>", rank=3)]
pub fn member_management_core_data_post(
    cookie: SessionCookie,
    settings: State<Settings>,
    action: String,
    id: String,
    form: Form<MemberProfileForm>,
) -> Result<Template, Status> {
    let caller = match cookie.member {
        //Unwraps member from cookie or send user to login if no member specified (user skipped member selection)
        Some(member) => member,
        None => return Err(Status::Unauthorized),
    };

    let member_uuid = match uuid::Uuid::from_str(&id) {
        Ok(uuid) => uuid,
        Err(e) => {
            warn!("Couldn't parse submitted member uuid (profile get): {}", e);
            return Err(Status::BadRequest);
        }
    };

    let member = match get_member_by_uuid(member_uuid, &settings) {
        Some(member) => member,
        None => return Err(Status::NotFound),
    };

    let address = get_addresses_for_entity_only_one_allowed(&settings, member_uuid);

    update_member(&settings, form.into_inner(), member.clone(), address, false);

    //Refresh member data after update
    let member = match get_member_by_uuid(member_uuid, &settings) {
        Some(member) => member,
        None => return Err(Status::NotFound),
    };

    //TODO: check permissions

    match action.as_ref() {
        "view" => handle_view(&settings, member, caller),
        "edit" => handle_edit(&settings, member, caller),
        _ => return Err(Status::NotFound),
    }
}
