use crate::helper::settings::Settings;
use rocket::State;
use crate::database::controller::users::get_user_by_email;
use crate::database::controller::password_resets::add_token;
use crate::helper::mail_templates::MailTemplates;
use crate::helper::mail_queue::queue::{Mail, MailQueue};
use std::sync::Arc;

#[derive(Serialize)]
pub struct PasswortResetMail{
    frontpage: String,
    email: String,
    reset_url: String,
}

/// Checks if email belongs to user, if so resets password
pub fn request_password_reset(settings: &State<Settings>, mt: &State<MailTemplates>, mq: State<Arc<MailQueue>>, email: String) -> Result<(), ()>{
    let user = match get_user_by_email(email.clone(), settings){ //Check if email belongs to user, if not return
        Some(user) => user,
        None => return Ok(()),
    };

    let token = match add_token(settings, user.id){
        Ok(token) => token,
        Err(e) => return Err(()),
    };
    let pwrm = PasswortResetMail{
        frontpage: settings.application.url.clone(),
        email: email.clone(),
        reset_url: format!("{}password_reset?token={}", settings.application.url.clone(), token)
    };
    let body = match mt.registry.render("password-reset-de", &pwrm){
        Ok(body) => body,
        Err(e) => return Err(()),
    };
    let mail = Mail::new(settings.mail.from.clone(), vec![email], format!("[{}] - Passwort Zurücksetzen", settings.application.name.clone()), vec![], vec![], Some(settings.mail.reply_to.clone()), body, None); //TODO: Add deliver_until

    match mq.add_mail(mail){
        Ok(_) => Ok(()),
        Err(_) => Err(())
    }
}