use std::error;
use std::error::Error as _;
use std::fmt;

#[derive(Debug)]
pub enum LoginError {
    UserNotFound,
    MaxLoginAttemptsExceeded,
    PasswordIncorrect,
    DatabaseError,
    NoPassword
}

impl fmt::Display for LoginError {
    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
        match *self {
            LoginError::UserNotFound =>
                write!(f, "User not found"),
            LoginError::MaxLoginAttemptsExceeded =>
                write!(f, "Maximum login attempts exceeded"),
            LoginError::PasswordIncorrect =>
                write!(f, "Password incorrect"),
            LoginError::DatabaseError => write!(f, "Database Error occured!"),
            LoginError::NoPassword => write!(f, "User missing password! No login possible."),
        }
    }
}

impl error::Error for LoginError {
    fn source(&self) -> Option<&(dyn error::Error + 'static)> {
        None
    }
}