use crate::helper::sitebuilder::model::alerts::{Alert, AlertClass};
use crate::modules::welcome::controller::render::get_context;
use rocket::http::Status;
use rocket_contrib::templates::Template;
use rocket::State;
use std::sync::Arc;

#[get("/?<error>")]
pub fn welcome_get(error: Option<String>) -> Result<Template, Status> {
    let alert = match error {
        Some(error) => match error.as_str() {
            "unauthorized" => Some(Alert::new(
                AlertClass::Warning,
                "Session ungültig oder abgelaufen. Bitte erneut anmelden!".to_string(),
            )),
            "logout_success" => Some(Alert::new(
                AlertClass::Success,
                "Sie wurden erfolgreich abgemeldet!".to_string(),
            )),
            "password_reset_success" => Some(Alert::new(
                AlertClass::Success,
                "Ihr Passwort wurde erfolgreich zurückgesetzt!".to_string(),
            )),
            "password_reset_token_invalid" => Some(Alert::new(AlertClass::Danger, "Der Passwort zurücksetzen Token ist ungültig! Bitte einen neuen Anfordern!".to_string())),
            "notimplemented" => Some(Alert::new(
                AlertClass::Danger,
                "Fehler: Diese Funktion wurde noch nicht implementiert!".to_string(),
            )),
            _ => None,
        },
        None => None,
    };
    Ok(Template::render("module_welcome", &get_context(alert)))
}
