table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    addresses (id) {
        id -> Uuid,
        title -> Nullable<Text>,
        street -> Nullable<Text>,
        number -> Nullable<Text>,
        zipcode -> Nullable<Text>,
        city -> Nullable<Text>,
        country -> Nullable<Text>,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    addresses_entities (address_id, entitiy_id) {
        address_id -> Uuid,
        entitiy_id -> Uuid,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    buildings (entity_id) {
        entity_id -> Uuid,
        name -> Text,
        description -> Nullable<Text>,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    communication_targets (target_id) {
        target_id -> Uuid,
        entity_id -> Uuid,
        com_type -> Uuid,
        value -> Text,
        description -> Nullable<Text>,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    communication_types (type_id) {
        type_id -> Uuid,
        type_name -> Text,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    cost_centres (short_id) {
        short_id -> Int4,
        description -> Nullable<Text>,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    cost_centres_members (member_entity_id, cost_centre_shortid) {
        member_entity_id -> Uuid,
        cost_centre_shortid -> Int4,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    entities (entity_id) {
        entity_id -> Uuid,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    groups (entity_id) {
        entity_id -> Uuid,
        group_name -> Text,
        group_description -> Nullable<Text>,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    groups_entities (group_id, entity_id) {
        group_id -> Uuid,
        entity_id -> Uuid,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    license_categories (name) {
        name -> Text,
        description -> Nullable<Text>,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    licenses_members (member_id, license_name) {
        member_id -> Uuid,
        license_name -> Text,
        drive_permission -> Bool,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    login_attempts (id) {
        id -> Uuid,
        email -> Text,
        timestamp -> Timestamp,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    members (entity_id) {
        entity_id -> Uuid,
        users_id -> Nullable<Uuid>,
        firstname -> Text,
        lastname -> Text,
        date_of_birth -> Nullable<Date>,
        sex -> Nullable<Int2>,
        salutation -> Nullable<Text>,
        place_of_birth -> Nullable<Text>,
        academic_titles -> Nullable<Text>,
        personnel_number -> Nullable<Int4>,
        ui_language -> Nullable<Text>,
        nationality -> Nullable<Text>,
        entrance_date -> Nullable<Date>,
        birth_name -> Nullable<Text>,
        iban -> Nullable<Text>,
        bic -> Nullable<Text>,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    members_roles (member_id, role_id) {
        member_id -> Uuid,
        role_id -> Text,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    password_resets (token) {
        token -> Text,
        user_id -> Uuid,
        issued -> Timestamp,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    permissions (permission) {
        permission -> Text,
        description -> Nullable<Text>,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    qualification_categories (id) {
        id -> Uuid,
        name -> Text,
        description -> Nullable<Text>,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    qualifications (id) {
        id -> Uuid,
        name -> Text,
        description -> Nullable<Text>,
        category -> Uuid,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    qualifications_members (member_id, qualification_id) {
        member_id -> Uuid,
        qualification_id -> Uuid,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    roles (id) {
        id -> Text,
        description -> Nullable<Text>,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    roles_permissions (role_permission_id) {
        role_id -> Text,
        permission_id -> Text,
        role_permission_id -> Uuid,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    roles_permissions_context (role_permission_id, entity) {
        role_permission_id -> Uuid,
        entity -> Uuid,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    units (unit_id) {
        unit_id -> Uuid,
        name -> Text,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    units_members (unit_id, member_id) {
        unit_id -> Uuid,
        member_id -> Uuid,
        crew -> Int2,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    users (id) {
        id -> Uuid,
        password -> Nullable<Text>,
        email -> Text,
    }
}

table! {
    use diesel::sql_types::*;
    use diesel_geometry::sql_types::*;

    vehicles (entity_id) {
        entity_id -> Uuid,
        identifier -> Text,
        numberplate -> Nullable<Text>,
        description -> Nullable<Text>,
        next_inspection -> Nullable<Date>,
        is_operational -> Bool,
        admissible_total_weight -> Nullable<Float4>,
        required_license -> Nullable<Text>,
    }
}

joinable!(addresses_entities -> addresses (address_id));
joinable!(addresses_entities -> entities (entitiy_id));
joinable!(buildings -> entities (entity_id));
joinable!(communication_targets -> communication_types (com_type));
joinable!(communication_targets -> entities (entity_id));
joinable!(cost_centres_members -> cost_centres (cost_centre_shortid));
joinable!(cost_centres_members -> members (member_entity_id));
joinable!(groups -> entities (entity_id));
joinable!(groups_entities -> entities (entity_id));
joinable!(groups_entities -> groups (group_id));
joinable!(licenses_members -> license_categories (license_name));
joinable!(licenses_members -> members (member_id));
joinable!(members -> entities (entity_id));
joinable!(members -> users (users_id));
joinable!(members_roles -> entities (member_id));
joinable!(members_roles -> roles (role_id));
joinable!(password_resets -> users (user_id));
joinable!(qualifications -> qualification_categories (category));
joinable!(qualifications_members -> members (member_id));
joinable!(qualifications_members -> qualifications (qualification_id));
joinable!(roles_permissions -> permissions (permission_id));
joinable!(roles_permissions -> roles (role_id));
joinable!(roles_permissions_context -> entities (entity));
joinable!(roles_permissions_context -> roles_permissions (role_permission_id));
joinable!(units -> entities (unit_id));
joinable!(units_members -> members (member_id));
joinable!(units_members -> units (unit_id));
joinable!(vehicles -> entities (entity_id));
joinable!(vehicles -> license_categories (required_license));

allow_tables_to_appear_in_same_query!(
    addresses,
    addresses_entities,
    buildings,
    communication_targets,
    communication_types,
    cost_centres,
    cost_centres_members,
    entities,
    groups,
    groups_entities,
    license_categories,
    licenses_members,
    login_attempts,
    members,
    members_roles,
    password_resets,
    permissions,
    qualification_categories,
    qualifications,
    qualifications_members,
    roles,
    roles_permissions,
    roles_permissions_context,
    units,
    units_members,
    users,
    vehicles,
);
